@@ -102,16 +102,35 @@ class BlockTests(testing.TestCase):
             {
                 'bytes_used': None,
                 'capacity_gb': 20,
-                'datacenter': None,
+                'datacenter': 'dal05',
                 'id': 100,
                 'ip_addr': '10.1.2.3',
                 'lunId': None,
+                'rep_partner_count': None,
                 'storage_type': 'ENDURANCE',
                 'username': 'username',
                 'active_transactions': None
             }],
             json.loads(result.output))
 
+    @mock.patch('SoftLayer.BlockStorageManager.list_block_volumes')
+    def test_volume_count(self, list_mock):
+        list_mock.return_value = [
+            {'serviceResource': {'datacenter': {'name': 'dal05'}}},
+            {'serviceResource': {'datacenter': {'name': 'ams01'}}},
+            {'serviceResource': {'datacenter': {'name': 'dal05'}}}
+        ]
+
+        result = self.run_command(['block', 'volume-count'])
+
+        self.assert_no_fail(result)
+        self.assertEqual(
+            {
+                'dal05': 2,
+                'ams01': 1
+            },
+            json.loads(result.output))
+
     def test_volume_order_performance_iops_not_given(self):
         result = self.run_command(['block', 'volume-order',
                                    '--storage-type=performance', '--size=20',
@@ -119,14 +138,6 @@ class BlockTests(testing.TestCase):
 
         self.assertEqual(2, result.exit_code)
 
-    def test_volume_order_performance_iops_out_of_range(self):
-        result = self.run_command(['block', 'volume-order',
-                                   '--storage-type=performance', '--size=20',
-                                   '--iops=80000', '--os-type=linux',
-                                   '--location=dal05'])
-
-        self.assertEqual(2, result.exit_code)
-
     def test_volume_order_performance_iops_not_multiple_of_100(self):
         result = self.run_command(['block', 'volume-order',
                                    '--storage-type=performance', '--size=20',
@@ -139,7 +150,8 @@ class BlockTests(testing.TestCase):
         result = self.run_command(['block', 'volume-order',
                                    '--storage-type=performance', '--size=20',
                                    '--iops=100', '--os-type=linux',
-                                   '--location=dal05', '--snapshot-size=10'])
+                                   '--location=dal05', '--snapshot-size=10',
+                                   '--service-offering=performance'])
 
         self.assertEqual(2, result.exit_code)
 
@@ -152,20 +164,22 @@ class BlockTests(testing.TestCase):
                     {'description': 'Performance Storage'},
                     {'description': 'Block Storage'},
                     {'description': '0.25 IOPS per GB'},
-                    {'description': '20 GB Storage Space'}]
+                    {'description': '20 GB Storage Space'},
+                    {'description': '10 GB Storage Space (Snapshot Space)'}]
             }
         }
 
         result = self.run_command(['block', 'volume-order',
                                    '--storage-type=performance', '--size=20',
                                    '--iops=100', '--os-type=linux',
-                                   '--location=dal05'])
+                                   '--location=dal05', '--snapshot-size=10'])
 
         self.assert_no_fail(result)
         self.assertEqual(result.output,
                          'Order #478 placed successfully!\n'
                          ' > Performance Storage\n > Block Storage\n'
-                         ' > 0.25 IOPS per GB\n > 20 GB Storage Space\n')
+                         ' > 0.25 IOPS per GB\n > 20 GB Storage Space\n'
+                         ' > 10 GB Storage Space (Snapshot Space)\n')
 
     def test_volume_order_endurance_tier_not_given(self):
         result = self.run_command(['block', 'volume-order',
@@ -297,6 +311,28 @@ class BlockTests(testing.TestCase):
         self.assertEqual(result.output, 'Block volume 12345678 is being'
                          ' restored using snapshot 87654321\n')
 
+    @mock.patch('SoftLayer.BlockStorageManager.order_snapshot_space')
+    def test_snapshot_order_order_not_placed(self, order_mock):
+        order_mock.return_value = {}
+
+        result = self.run_command(['block', 'snapshot-order', '1234',
+                                   '--capacity=10', '--tier=0.25'])
+
+        self.assert_no_fail(result)
+        self.assertEqual(result.output,
+                         'Order could not be placed! Please verify '
+                         'your options and try again.\n')
+
+    @mock.patch('SoftLayer.BlockStorageManager.order_snapshot_space')
+    def test_snapshot_order_performance_manager_error(self, order_mock):
+        order_mock.side_effect = ValueError('failure!')
+
+        result = self.run_command(['block', 'snapshot-order', '1234',
+                                   '--capacity=10', '--tier=0.25'])
+
+        self.assertEqual(2, result.exit_code)
+        self.assertEqual('Argument Error: failure!', result.exception.message)
+
     @mock.patch('SoftLayer.BlockStorageManager.order_snapshot_space')
     def test_snapshot_order(self, order_mock):
         order_mock.return_value = {
@@ -354,6 +390,7 @@ class BlockTests(testing.TestCase):
     def test_replication_locations_unsuccessful(self, locations_mock):
         locations_mock.return_value = False
         result = self.run_command(['block', 'replica-locations', '1234'])
+        self.assert_no_fail(result)
         self.assertEqual('No data centers compatible for replication.\n',
                          result.output)
 
